From: Greg KH <gregkh@suse.de>
To: linux-kernel@vger.kernel.org, stable@kernel.org
Cc: stable-review@kernel.org, torvalds@linux-foundation.org,
akpm@linux-foundation.org, alan@lxorguk.ukuu.org.uk,
Takashi Iwai <tiwai@suse.de>
Subject: [patch 01/48] ALSA: hda - Fix MacBookPro 3,1/4,1 quirk with ALC889A
Date: Fri, 04 Sep 2009 13:07:13 -0700 [thread overview]
Message-ID: <20090904200850.052613921@mini.kroah.org> (raw)
In-Reply-To: <20090904201112.GA8274@kroah.com>
[-- Attachment #1: alsa-hda-fix-macbookpro-3-1-4-1-quirk-with-alc889a.patch --]
[-- Type: text/plain, Size: 4071 bytes --]
2.6.27-stable review patch. If anyone has any objections, please let us know.
------------------
From: Takashi Iwai <tiwai@suse.de>
commit a3f730af7e33cea10ea66f05b2565fde1f9512df upstream.
This patch fixes the wrong headphone output routing for MacBookPro 3,1/4,1
quirk with ALC889A codec, which caused the silent headphone output.
Also, this gives the individual Headphone and Speaker volume controls.
Reference: kernel bug#14078
http://bugzilla.kernel.org/show_bug.cgi?id=14078
Signed-off-by: Takashi Iwai <tiwai@suse.de>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
---
sound/pci/hda/patch_realtek.c | 34 ++++++++++++++++++++--------------
1 file changed, 20 insertions(+), 14 deletions(-)
--- a/sound/pci/hda/patch_realtek.c
+++ b/sound/pci/hda/patch_realtek.c
@@ -5580,9 +5580,9 @@ static struct hda_verb alc885_mbp_ch2_in
};
/*
- * 6ch mode
+ * 4ch mode
*/
-static struct hda_verb alc885_mbp_ch6_init[] = {
+static struct hda_verb alc885_mbp_ch4_init[] = {
{ 0x1a, AC_VERB_SET_PIN_WIDGET_CONTROL, PIN_OUT },
{ 0x1a, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_UNMUTE},
{ 0x1a, AC_VERB_SET_CONNECT_SEL, 0x01 },
@@ -5591,9 +5591,9 @@ static struct hda_verb alc885_mbp_ch6_in
{ } /* end */
};
-static struct hda_channel_mode alc885_mbp_6ch_modes[2] = {
+static struct hda_channel_mode alc885_mbp_4ch_modes[2] = {
{ 2, alc885_mbp_ch2_init },
- { 6, alc885_mbp_ch6_init },
+ { 4, alc885_mbp_ch4_init },
};
@@ -5628,10 +5628,11 @@ static struct snd_kcontrol_new alc882_ba
};
static struct snd_kcontrol_new alc885_mbp3_mixer[] = {
- HDA_CODEC_VOLUME("Front Playback Volume", 0x0c, 0x00, HDA_OUTPUT),
- HDA_BIND_MUTE ("Front Playback Switch", 0x0c, 0x02, HDA_INPUT),
- HDA_CODEC_MUTE ("Speaker Playback Switch", 0x14, 0x00, HDA_OUTPUT),
- HDA_CODEC_VOLUME("Line-Out Playback Volume", 0x0d, 0x00, HDA_OUTPUT),
+ HDA_CODEC_VOLUME("Speaker Playback Volume", 0x0c, 0x00, HDA_OUTPUT),
+ HDA_BIND_MUTE ("Speaker Playback Switch", 0x0c, 0x02, HDA_INPUT),
+ HDA_CODEC_VOLUME("Headphone Playback Volume", 0x0e, 0x00, HDA_OUTPUT),
+ HDA_BIND_MUTE ("Headphone Playback Switch", 0x0e, 0x02, HDA_INPUT),
+ HDA_CODEC_VOLUME("Surround Playback Volume", 0x0d, 0x00, HDA_OUTPUT),
HDA_CODEC_VOLUME("Line Playback Volume", 0x0b, 0x02, HDA_INPUT),
HDA_CODEC_MUTE ("Line Playback Switch", 0x0b, 0x02, HDA_INPUT),
HDA_CODEC_VOLUME("Mic Playback Volume", 0x0b, 0x00, HDA_INPUT),
@@ -5879,14 +5880,18 @@ static struct hda_verb alc885_mbp3_init_
{0x0d, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_ZERO},
{0x0d, AC_VERB_SET_AMP_GAIN_MUTE, AMP_IN_MUTE(0)},
{0x0d, AC_VERB_SET_AMP_GAIN_MUTE, AMP_IN_MUTE(1)},
+ /* HP mixer */
+ {0x0e, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_ZERO},
+ {0x0e, AC_VERB_SET_AMP_GAIN_MUTE, AMP_IN_MUTE(0)},
+ {0x0e, AC_VERB_SET_AMP_GAIN_MUTE, AMP_IN_MUTE(1)},
/* Front Pin: output 0 (0x0c) */
{0x14, AC_VERB_SET_PIN_WIDGET_CONTROL, PIN_OUT},
{0x14, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_UNMUTE},
{0x14, AC_VERB_SET_CONNECT_SEL, 0x00},
/* HP Pin: output 0 (0x0d) */
{0x15, AC_VERB_SET_PIN_WIDGET_CONTROL, 0xc4},
- {0x15, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_MUTE},
- {0x15, AC_VERB_SET_CONNECT_SEL, 0x00},
+ {0x15, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_UNMUTE},
+ {0x15, AC_VERB_SET_CONNECT_SEL, 0x02},
{0x15, AC_VERB_SET_UNSOLICITED_ENABLE, ALC880_HP_EVENT | AC_USRSP_EN},
/* Mic (rear) pin: input vref at 80% */
{0x18, AC_VERB_SET_PIN_WIDGET_CONTROL, PIN_VREF80},
@@ -6326,10 +6331,11 @@ static struct alc_config_preset alc882_p
.mixers = { alc885_mbp3_mixer, alc882_chmode_mixer },
.init_verbs = { alc885_mbp3_init_verbs,
alc880_gpio1_init_verbs },
- .num_dacs = ARRAY_SIZE(alc882_dac_nids),
+ .num_dacs = 2,
.dac_nids = alc882_dac_nids,
- .channel_mode = alc885_mbp_6ch_modes,
- .num_channel_mode = ARRAY_SIZE(alc885_mbp_6ch_modes),
+ .hp_nid = 0x04,
+ .channel_mode = alc885_mbp_4ch_modes,
+ .num_channel_mode = ARRAY_SIZE(alc885_mbp_4ch_modes),
.input_mux = &alc882_capture_source,
.dig_out_nid = ALC882_DIGOUT_NID,
.dig_in_nid = ALC882_DIGIN_NID,
next prev parent reply other threads:[~2009-09-04 20:14 UTC|newest]
Thread overview: 56+ messages / expand[flat|nested] mbox.gz Atom feed top
[not found] <20090904200712.724048145@mini.kroah.org>
2009-09-04 20:11 ` [patch 00/48] 2.6.27.32-stable review Greg KH
2009-09-04 20:07 ` Greg KH [this message]
2009-09-04 20:07 ` [patch 02/48] clone(): fix race between copy_process() and de_thread() Greg KH
2009-09-04 20:07 ` [patch 03/48] ehea: Fix napi list corruption on ifconfig down Greg KH
2009-09-04 20:07 ` [patch 04/48] sound: pcm_lib: fix unsorted list constraint handling Greg KH
2009-09-04 20:07 ` [patch 05/48] SUNRPC: Fix rpc_task_force_reencode Greg KH
2009-09-04 20:07 ` [patch 06/48] KVM: VMX: Change cs reset state to be a data segment Greg KH
2009-09-04 20:07 ` [patch 07/48] KVM: VMX: Change segment dpl at reset to 3 Greg KH
2009-09-04 20:07 ` [patch 08/48] KVM: Load real mode segments correctly Greg KH
2009-09-04 20:07 ` [patch 09/48] KVM: Allocate guest memory as MAP_PRIVATE, not MAP_SHARED Greg KH
2009-09-04 20:07 ` [patch 10/48] KVM: Dont call get_user_pages(.force = 1) Greg KH
2009-09-04 20:07 ` [patch 11/48] KVM: MMU: Add locking around kvm_mmu_slot_remove_write_access() Greg KH
2009-09-04 20:07 ` [patch 12/48] KVM: MMU: Flush tlbs after clearing write permission when accessing dirty log Greg KH
2009-09-04 20:07 ` [patch 13/48] KVM: MMU: Fix setting the accessed bit on non-speculative sptes Greg KH
2009-09-04 20:07 ` [patch 14/48] KVM: Reduce kvm stack usage in kvm_arch_vm_ioctl() Greg KH
2009-09-06 5:47 ` Pavel Machek
2009-09-06 13:43 ` Dave Hansen
2009-09-04 20:07 ` [patch 15/48] KVM: Reduce stack usage in kvm_vcpu_ioctl() Greg KH
2009-09-04 20:07 ` [patch 16/48] KVM: Reduce stack usage in kvm_arch_vcpu_ioctl() Greg KH
2009-09-04 20:07 ` [patch 17/48] KVM: Reduce stack usage in kvm_pv_mmu_op() Greg KH
2009-09-04 20:07 ` [patch 18/48] KVM: add MC5_MISC msr read support Greg KH
2009-09-04 20:07 ` [patch 19/48] KVM: set debug registers after "schedulable" section Greg KH
2009-09-04 20:07 ` [patch 20/48] KVM: MMU: increase per-vcpu rmap cache alloc size Greg KH
2009-09-04 20:07 ` [patch 21/48] KVM: VMX: Set IGMT bit in EPT entry Greg KH
2009-09-04 20:07 ` [patch 22/48] KVM: Dont destroy vcpu in case vcpu_setup fails Greg KH
2009-09-04 20:07 ` [patch 23/48] KVM: VMX: Dont allow uninhibited access to EFER on i386 Greg KH
2009-09-04 20:07 ` [patch 24/48] KVM: SVM: Remove port 80 passthrough Greg KH
2009-09-04 20:07 ` [patch 25/48] KVM: Make EFER reads safe when EFER does not exist Greg KH
2009-09-04 20:07 ` [patch 26/48] KVM: VMX: Handle vmx instruction vmexits Greg KH
2009-09-04 20:07 ` [patch 27/48] KVM: Make paravirt tlb flush also reload the PAE PDPTRs Greg KH
2009-09-04 20:07 ` [patch 28/48] KVM: Fix PDPTR reloading on CR4 writes Greg KH
2009-09-04 20:07 ` [patch 29/48] KVM: MMU: do not free active mmu pages in free_mmu_pages() Greg KH
2009-09-04 20:07 ` [patch 30/48] KVM: Fix dirty bit tracking for slots with large pages Greg KH
2009-09-04 20:07 ` [patch 31/48] KVM: x86: check for cr3 validity in mmu_alloc_roots Greg KH
2009-09-04 20:07 ` [patch 32/48] KVM: MMU: protect kvm_mmu_change_mmu_pages with mmu_lock Greg KH
2009-09-04 20:07 ` [patch 33/48] appletalk: fix atalk_getname() leak Greg KH
2009-09-04 20:07 ` [patch 34/48] can: Fix raw_getname() leak Greg KH
2009-09-04 20:07 ` [patch 35/48] do_sigaltstack: avoid copying stack_t as a structure to user space Greg KH
2009-09-04 20:07 ` [patch 36/48] econet: Fix econet_getname() leak Greg KH
2009-09-04 20:07 ` [patch 37/48] irda: Fix irda_getname() leak Greg KH
2009-09-04 20:07 ` [patch 38/48] kthreads: fix kthread_create() vs kthread_stop() race Greg KH
2009-09-04 20:07 ` [patch 39/48] NET: llc, zero sockaddr_llc struct Greg KH
2009-09-04 20:07 ` [patch 40/48] netrom: Fix nr_getname() leak Greg KH
2009-09-04 20:07 ` [patch 41/48] ocfs2: Initialize the cluster were writing to in a non-sparse extend Greg KH
2009-09-04 21:00 ` Joel Becker
2009-09-06 8:32 ` Joel Becker
2009-09-06 18:17 ` Greg KH
2009-09-04 20:07 ` [patch 42/48] rose: Fix rose_getname() leak Greg KH
2009-09-04 20:07 ` [patch 43/48] ALSA: hda - Add missing vmaster initialization for ALC269 Greg KH
2009-09-04 20:07 ` [patch 44/48] parport: quickfix the proc registration bug Greg KH
2009-09-04 20:07 ` [patch 45/48] USB: removal of tty->low_latency hack dating back to the old serial code Greg KH
2009-09-04 20:07 ` [patch 46/48] Remove low_latency flag setting from nozomi and mxser drivers Greg KH
2009-09-04 20:07 ` [patch 47/48] SCSI: sr: report more accurate drive status after closing the tray Greg KH
2009-09-04 20:08 ` [patch 48/48] SUNRPC: Fix tcp reconnection Greg KH
2009-09-06 22:58 ` [patch 00/48] 2.6.27.32-stable review Tilman Schmidt
2009-09-10 22:33 ` Greg KH
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20090904200850.052613921@mini.kroah.org \
--to=gregkh@suse.de \
--cc=akpm@linux-foundation.org \
--cc=alan@lxorguk.ukuu.org.uk \
--cc=linux-kernel@vger.kernel.org \
--cc=stable-review@kernel.org \
--cc=stable@kernel.org \
--cc=tiwai@suse.de \
--cc=torvalds@linux-foundation.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -5879,14 +5880,18 @@ static struct hda_verb alc885_mbp3_init_
{0x14, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_UNMUTE},
{0x14, AC_VERB_SET_CONNECT_SEL, 0x00},
- /* HP Pin: output 0 (0x0d) */
+ /* HP Pin: output 0 (0x0e) */
{0x15, AC_VERB_SET_PIN_WIDGET_CONTROL, 0xc4},
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox